@@ -103,7 +103,7 @@ options:
       - Specifies an existing volume group (VG).
     type: str
 notes:
-  - For more O(attributes), please check "crfs" AIX manual.
+  - For more O(attributes), please check C(crfs) AIX manual.
 """
 
 EXAMPLES = r"""
@@ -165,7 +165,7 @@ EXAMPLES = r"""
 
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.general.plugins.module_utils._mount import ismount
+from os.path import ismount
 import re
 
 
@@ -205,11 +205,7 @@ def _check_nfs_device(module, nfs_host, device):
         module.fail_json(msg=f"Failed to run showmount. Error message: {err}")
     else:
         showmount_data = showmount_out.splitlines()
-        for line in showmount_data:
-            if line.split(":")[1] == device:
-                return True
-
-        return False
+        return any(line.split(":")[1] == device for line in showmount_data)
 
 
 def _validate_vg(module, vg):
