@@ -16,7 +16,6 @@ short_description: Configure DLP profiles.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.1.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -253,6 +252,14 @@ options:
                     - 'mapi'
                     - 'ssh'
                     - 'cifs'
+            fortidata_error_action:
+                aliases: ['fortidata-error-action']
+                type: str
+                description: Action to take if FortiData query fails.
+                choices:
+                    - 'block'
+                    - 'log-only'
+                    - 'ignore'
 '''
 
 EXAMPLES = '''
@@ -330,6 +337,7 @@ EXAMPLES = '''
           #   - "mapi"
           #   - "ssh"
           #   - "cifs"
+          # fortidata_error_action: <value in [block, log-only, ignore]>
 '''
 
 RETURN = '''
@@ -440,7 +448,8 @@ def main():
                     'type': 'list',
                     'choices': ['smtp', 'pop3', 'imap', 'http-post', 'http-get', 'ftp', 'nntp', 'mapi', 'ssh', 'cifs'],
                     'elements': 'str'
-                }
+                },
+                'fortidata-error-action': {'v_range': [['7.6.4', '']], 'choices': ['block', 'log-only', 'ignore'], 'type': 'str'}
             }
         }
     }
