@@ -16,7 +16,6 @@ short_description: Set up DLP filters for this sensor.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -207,6 +209,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -215,8 +218,8 @@ EXAMPLES = '''
     - name: Set up DLP filters for this sensor.
       fortinet.fortimanager.fmgr_dlp_sensor_filter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -314,6 +317,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'sensor': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'dlp_sensor_filter': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -331,7 +335,7 @@ def main():
                     'choices': ['credit-card', 'ssn', 'regexp', 'file-type', 'file-size', 'fingerprint', 'watermark', 'encrypted', 'file-type-and-size'],
                     'type': 'str'
                 },
-                'fp-sensitivity': {'v_range': [['6.0.0', '7.2.1']], 'type': 'raw'},
+                'fp-sensitivity': {'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']], 'type': 'raw'},
                 'id': {'required': True, 'type': 'int'},
                 'match-percentage': {'type': 'int'},
                 'name': {'type': 'str'},
