@@ -16,7 +16,6 @@ short_description: Device group table.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -105,6 +104,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -113,16 +113,16 @@ EXAMPLES = '''
     - name: Device group table.
       fortinet.fortimanager.fmgr_dvmdb_group_objectmember:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         group: <your own value>
         state: present # <value in [present, absent]>
         dvmdb_group_objectmember:
-          name: <string>
-          vdom: <string>
+          # name: <string>
+          # vdom: <string>
 '''
 
 RETURN = '''
@@ -166,23 +166,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/dvmdb/adom/{adom}/group/{group}/object member',
         '/dvmdb/group/{group}/object member'
     ]
-
-    perobject_jrpc_urls = [
-        '/dvmdb/adom/{adom}/group/{group}/object member',
-        '/dvmdb/group/{group}/object member'
-    ]
-
     url_params = ['adom', 'group']
     module_primary_key = None
     module_arg_spec = {
@@ -192,7 +184,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'name': {'type': 'str'}, 'vdom': {'type': 'str'}}
-
         }
     }
 
@@ -201,14 +192,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dvmdb_group_objectmember'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('object member', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_object_member(argument_specs=module_arg_spec)
+    fmgr.process_object_member()
 
     module.exit_json(meta=module.params)
 
