@@ -16,7 +16,6 @@ short_description: FortiExtender wifi configuration.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.6.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -64,6 +63,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -292,13 +294,16 @@ options:
                     - 'YT'
                     - 'BL'
                     - '--'
-            radio-1:
+                    - 'TL'
+            radio_1:
+                aliases: ['radio-1']
                 type: dict
-                description: Deprecated, please rename it to radio_1. Radio 1.
+                description: Radio 1.
                 suboptions:
-                    80211d:
+                    d80211d:
+                        aliases: ['80211d']
                         type: str
-                        description: Deprecated, please rename it to d80211d. Enable/disable Wi-Fi 802.
+                        description: Enable/disable Wi-Fi 802.
                         choices:
                             - 'disable'
                             - 'enable'
@@ -315,15 +320,18 @@ options:
                             - '20MHz'
                             - '40MHz'
                             - '80MHz'
-                    beacon-interval:
+                    beacon_interval:
+                        aliases: ['beacon-interval']
                         type: int
-                        description: Deprecated, please rename it to beacon_interval. Wi-Fi beacon interval in miliseconds
-                    bss-color:
+                        description: Wi-Fi beacon interval in miliseconds
+                    bss_color:
+                        aliases: ['bss-color']
                         type: int
-                        description: Deprecated, please rename it to bss_color. Wi-Fi 802.
-                    bss-color-mode:
+                        description: Wi-Fi 802.
+                    bss_color_mode:
+                        aliases: ['bss-color-mode']
                         type: str
-                        description: Deprecated, please rename it to bss_color_mode. Wi-Fi 802.
+                        description: Wi-Fi 802.
                         choices:
                             - 'auto'
                             - 'static'
@@ -343,40 +351,46 @@ options:
                             - 'CH9'
                             - 'CH10'
                             - 'CH11'
-                    extension-channel:
+                    extension_channel:
+                        aliases: ['extension-channel']
                         type: str
-                        description: Deprecated, please rename it to extension_channel. Wi-Fi extension channel.
+                        description: Wi-Fi extension channel.
                         choices:
                             - 'auto'
                             - 'higher'
                             - 'lower'
-                    guard-interval:
+                    guard_interval:
+                        aliases: ['guard-interval']
                         type: str
-                        description: Deprecated, please rename it to guard_interval. Wi-Fi guard interval.
+                        description: Wi-Fi guard interval.
                         choices:
                             - 'auto'
                             - '400ns'
                             - '800ns'
-                    lan-ext-vap:
+                    lan_ext_vap:
+                        aliases: ['lan-ext-vap']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to lan_ext_vap. Wi-Fi LAN-Extention VAP.
-                    local-vaps:
+                        description: Wi-Fi LAN-Extention VAP.
+                    local_vaps:
+                        aliases: ['local-vaps']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to local_vaps. Wi-Fi local VAP.
-                    max-clients:
+                        description: Wi-Fi local VAP.
+                    max_clients:
+                        aliases: ['max-clients']
                         type: int
-                        description: Deprecated, please rename it to max_clients. Maximum number of Wi-Fi radio clients
+                        description: Maximum number of Wi-Fi radio clients
                     mode:
                         type: str
                         description: Wi-Fi radio mode AP
                         choices:
                             - 'AP'
                             - 'Client'
-                    operating-standard:
+                    operating_standard:
+                        aliases: ['operating-standard']
                         type: str
-                        description: Deprecated, please rename it to operating_standard. Wi-Fi operating standard.
+                        description: Wi-Fi operating standard.
                         choices:
                             - 'auto'
                             - '11A-N-AC-AX'
@@ -397,25 +411,29 @@ options:
                             - '11G-N'
                             - '11N'
                             - '11G'
-                    power-level:
+                    power_level:
+                        aliases: ['power-level']
                         type: int
-                        description: Deprecated, please rename it to power_level. Wi-Fi power level in percent
-                    radio-id:
+                        description: Wi-Fi power level in percent
+                    radio_id:
+                        aliases: ['radio-id']
                         type: int
-                        description: Deprecated, please rename it to radio_id. Radio ID.
+                        description: Radio ID.
                     status:
                         type: str
                         description: Enable/disable Wi-Fi radio.
                         choices:
                             - 'disable'
                             - 'enable'
-            radio-2:
+            radio_2:
+                aliases: ['radio-2']
                 type: dict
-                description: Deprecated, please rename it to radio_2. Radio 2.
+                description: Radio 2.
                 suboptions:
-                    80211d:
+                    d80211d:
+                        aliases: ['80211d']
                         type: str
-                        description: Deprecated, please rename it to d80211d. Enable/disable Wi-Fi 802.
+                        description: Enable/disable Wi-Fi 802.
                         choices:
                             - 'disable'
                             - 'enable'
@@ -432,15 +450,18 @@ options:
                             - '20MHz'
                             - '40MHz'
                             - '80MHz'
-                    beacon-interval:
+                    beacon_interval:
+                        aliases: ['beacon-interval']
                         type: int
-                        description: Deprecated, please rename it to beacon_interval. Wi-Fi beacon interval in miliseconds
-                    bss-color:
+                        description: Wi-Fi beacon interval in miliseconds
+                    bss_color:
+                        aliases: ['bss-color']
                         type: int
-                        description: Deprecated, please rename it to bss_color. Wi-Fi 802.
-                    bss-color-mode:
+                        description: Wi-Fi 802.
+                    bss_color_mode:
+                        aliases: ['bss-color-mode']
                         type: str
-                        description: Deprecated, please rename it to bss_color_mode. Wi-Fi 802.
+                        description: Wi-Fi 802.
                         choices:
                             - 'auto'
                             - 'static'
@@ -474,40 +495,46 @@ options:
                             - 'CH157'
                             - 'CH161'
                             - 'CH165'
-                    extension-channel:
+                    extension_channel:
+                        aliases: ['extension-channel']
                         type: str
-                        description: Deprecated, please rename it to extension_channel. Wi-Fi extension channel.
+                        description: Wi-Fi extension channel.
                         choices:
                             - 'auto'
                             - 'higher'
                             - 'lower'
-                    guard-interval:
+                    guard_interval:
+                        aliases: ['guard-interval']
                         type: str
-                        description: Deprecated, please rename it to guard_interval. Wi-Fi guard interval.
+                        description: Wi-Fi guard interval.
                         choices:
                             - 'auto'
                             - '400ns'
                             - '800ns'
-                    lan-ext-vap:
+                    lan_ext_vap:
+                        aliases: ['lan-ext-vap']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to lan_ext_vap. Wi-Fi LAN-Extention VAP.
-                    local-vaps:
+                        description: Wi-Fi LAN-Extention VAP.
+                    local_vaps:
+                        aliases: ['local-vaps']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to local_vaps. Wi-Fi local VAP.
-                    max-clients:
+                        description: Wi-Fi local VAP.
+                    max_clients:
+                        aliases: ['max-clients']
                         type: int
-                        description: Deprecated, please rename it to max_clients. Maximum number of Wi-Fi radio clients
+                        description: Maximum number of Wi-Fi radio clients
                     mode:
                         type: str
                         description: Wi-Fi radio mode AP
                         choices:
                             - 'AP'
                             - 'Client'
-                    operating-standard:
+                    operating_standard:
+                        aliases: ['operating-standard']
                         type: str
-                        description: Deprecated, please rename it to operating_standard. Wi-Fi operating standard.
+                        description: Wi-Fi operating standard.
                         choices:
                             - 'auto'
                             - '11A-N-AC-AX'
@@ -528,12 +555,14 @@ options:
                             - '11G-N'
                             - '11N'
                             - '11G'
-                    power-level:
+                    power_level:
+                        aliases: ['power-level']
                         type: int
-                        description: Deprecated, please rename it to power_level. Wi-Fi power level in percent
-                    radio-id:
+                        description: Wi-Fi power level in percent
+                    radio_id:
+                        aliases: ['radio-id']
                         type: int
-                        description: Deprecated, please rename it to radio_id. Radio ID.
+                        description: Radio ID.
                     status:
                         type: str
                         description: Enable/disable Wi-Fi radio.
@@ -546,6 +575,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -554,87 +584,87 @@ EXAMPLES = '''
     - name: FortiExtender wifi configuration.
       fortinet.fortimanager.fmgr_extensioncontroller_extenderprofile_wifi:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         extender_profile: <your own value>
         extensioncontroller_extenderprofile_wifi:
-          DFS: <value in [disable, enable]>
-          country: <value in [AL, DZ, AR, ...]>
-          radio_1:
-            d80211d: <value in [disable, enable]>
-            band: <value in [2.4GHz]>
-            bandwidth: <value in [auto, 20MHz, 40MHz, ...]>
-            beacon_interval: <integer>
-            bss_color: <integer>
-            bss_color_mode: <value in [auto, static]>
-            channel:
-              - CH1
-              - CH2
-              - CH3
-              - CH4
-              - CH5
-              - CH6
-              - CH7
-              - CH8
-              - CH9
-              - CH10
-              - CH11
-            extension_channel: <value in [auto, higher, lower]>
-            guard_interval: <value in [auto, 400ns, 800ns]>
-            lan_ext_vap: <list or string>
-            local_vaps: <list or string>
-            max_clients: <integer>
-            mode: <value in [AP, Client]>
-            operating_standard: <value in [auto, 11A-N-AC-AX, 11A-N-AC, ...]>
-            power_level: <integer>
-            radio_id: <integer>
-            status: <value in [disable, enable]>
-          radio_2:
-            d80211d: <value in [disable, enable]>
-            band: <value in [5GHz]>
-            bandwidth: <value in [auto, 20MHz, 40MHz, ...]>
-            beacon_interval: <integer>
-            bss_color: <integer>
-            bss_color_mode: <value in [auto, static]>
-            channel:
-              - CH36
-              - CH40
-              - CH44
-              - CH48
-              - CH52
-              - CH56
-              - CH60
-              - CH64
-              - CH100
-              - CH104
-              - CH108
-              - CH112
-              - CH116
-              - CH120
-              - CH124
-              - CH128
-              - CH132
-              - CH136
-              - CH140
-              - CH144
-              - CH149
-              - CH153
-              - CH157
-              - CH161
-              - CH165
-            extension_channel: <value in [auto, higher, lower]>
-            guard_interval: <value in [auto, 400ns, 800ns]>
-            lan_ext_vap: <list or string>
-            local_vaps: <list or string>
-            max_clients: <integer>
-            mode: <value in [AP, Client]>
-            operating_standard: <value in [auto, 11A-N-AC-AX, 11A-N-AC, ...]>
-            power_level: <integer>
-            radio_id: <integer>
-            status: <value in [disable, enable]>
+          # DFS: <value in [disable, enable]>
+          # country: <value in [AL, DZ, AR, ...]>
+          # radio_1:
+          #   d80211d: <value in [disable, enable]>
+          #   band: <value in [2.4GHz]>
+          #   bandwidth: <value in [auto, 20MHz, 40MHz, ...]>
+          #   beacon_interval: <integer>
+          #   bss_color: <integer>
+          #   bss_color_mode: <value in [auto, static]>
+          #   channel:
+          #     - "CH1"
+          #     - "CH2"
+          #     - "CH3"
+          #     - "CH4"
+          #     - "CH5"
+          #     - "CH6"
+          #     - "CH7"
+          #     - "CH8"
+          #     - "CH9"
+          #     - "CH10"
+          #     - "CH11"
+          #   extension_channel: <value in [auto, higher, lower]>
+          #   guard_interval: <value in [auto, 400ns, 800ns]>
+          #   lan_ext_vap: <list or string>
+          #   local_vaps: <list or string>
+          #   max_clients: <integer>
+          #   mode: <value in [AP, Client]>
+          #   operating_standard: <value in [auto, 11A-N-AC-AX, 11A-N-AC, ...]>
+          #   power_level: <integer>
+          #   radio_id: <integer>
+          #   status: <value in [disable, enable]>
+          # radio_2:
+          #   d80211d: <value in [disable, enable]>
+          #   band: <value in [5GHz]>
+          #   bandwidth: <value in [auto, 20MHz, 40MHz, ...]>
+          #   beacon_interval: <integer>
+          #   bss_color: <integer>
+          #   bss_color_mode: <value in [auto, static]>
+          #   channel:
+          #     - "CH36"
+          #     - "CH40"
+          #     - "CH44"
+          #     - "CH48"
+          #     - "CH52"
+          #     - "CH56"
+          #     - "CH60"
+          #     - "CH64"
+          #     - "CH100"
+          #     - "CH104"
+          #     - "CH108"
+          #     - "CH112"
+          #     - "CH116"
+          #     - "CH120"
+          #     - "CH124"
+          #     - "CH128"
+          #     - "CH132"
+          #     - "CH136"
+          #     - "CH140"
+          #     - "CH144"
+          #     - "CH149"
+          #     - "CH153"
+          #     - "CH157"
+          #     - "CH161"
+          #     - "CH165"
+          #   extension_channel: <value in [auto, higher, lower]>
+          #   guard_interval: <value in [auto, 400ns, 800ns]>
+          #   lan_ext_vap: <list or string>
+          #   local_vaps: <list or string>
+          #   max_clients: <integer>
+          #   mode: <value in [AP, Client]>
+          #   operating_standard: <value in [auto, 11A-N-AC-AX, 11A-N-AC, ...]>
+          #   power_level: <integer>
+          #   radio_id: <integer>
+          #   status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -678,29 +708,22 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/wifi',
         '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/wifi'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/wifi/{wifi}',
-        '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/wifi/{wifi}'
-    ]
-
     url_params = ['adom', 'extender-profile']
     module_primary_key = None
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'extender-profile': {'type': 'str', 'api_name': 'extender_profile'},
         'extender_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'extensioncontroller_extenderprofile_wifi': {
             'type': 'dict',
             'v_range': [['7.4.3', '']],
@@ -718,7 +741,7 @@ def main():
                         'TD', 'BW', 'LY', 'RW', 'MZ', 'GM', 'LS', 'MU', 'CG', 'UG', 'BF', 'SL', 'SO', 'CD', 'NE', 'CF', 'SZ', 'TG', 'LR', 'MR', 'DJ',
                         'RE', 'RS', 'ME', 'IQ', 'MD', 'KY', 'BB', 'BM', 'TC', 'VI', 'PM', 'MF', 'GD', 'IM', 'FO', 'GI', 'GL', 'TM', 'MN', 'VU', 'FJ',
                         'LA', 'GU', 'WF', 'MH', 'BT', 'FM', 'PF', 'NI', 'PY', 'HT', 'GY', 'AW', 'KN', 'GF', 'AS', 'MP', 'PW', 'MM', 'LC', 'GP', 'ET',
-                        'SR', 'CX', 'DM', 'MQ', 'YT', 'BL', '--'
+                        'SR', 'CX', 'DM', 'MQ', 'YT', 'BL', '--', 'TL'
                     ],
                     'type': 'str'
                 },
@@ -796,7 +819,6 @@ def main():
                     }
                 }
             }
-
         }
     }
 
@@ -805,14 +827,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'extensioncontroller_extenderprofile_wifi'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
