@@ -16,7 +16,6 @@ short_description: Configure Access Proxy.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.1.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -261,6 +263,13 @@ options:
                                 choices:
                                     - 'disable'
                                     - 'enable'
+                            verify_cert:
+                                aliases: ['verify-cert']
+                                type: str
+                                description: Enable/disable certificate verification of the real server.
+                                choices:
+                                    - 'disable'
+                                    - 'enable'
                     saml_server:
                         aliases: ['saml-server']
                         type: str
@@ -808,6 +817,13 @@ options:
                                 choices:
                                     - 'disable'
                                     - 'enable'
+                            verify_cert:
+                                aliases: ['verify-cert']
+                                type: str
+                                description: Enable/disable certificate verification of the real server.
+                                choices:
+                                    - 'disable'
+                                    - 'enable'
                     saml_redirect:
                         aliases: ['saml-redirect']
                         type: str
@@ -1113,6 +1129,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -1121,8 +1138,8 @@ EXAMPLES = '''
     - name: Configure Access Proxy.
       fortinet.fortimanager.fmgr_firewall_accessproxy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -1161,6 +1178,7 @@ EXAMPLES = '''
           #         translate_host: <value in [disable, enable]>
           #         external_auth: <value in [disable, enable]>
           #         tunnel_encryption: <value in [disable, enable]>
+          #         verify_cert: <value in [disable, enable]>
           #     saml_server: <string>
           #     service: <value in [http, https, tcp-forwarding, ...]>
           #     ssl_algorithm: <value in [high, medium, low, ...]>
@@ -1249,6 +1267,7 @@ EXAMPLES = '''
           #         translate_host: <value in [disable, enable]>
           #         external_auth: <value in [disable, enable]>
           #         tunnel_encryption: <value in [disable, enable]>
+          #         verify_cert: <value in [disable, enable]>
           #     saml_redirect: <value in [disable, enable]>
           #     saml_server: <string>
           #     service: <value in [http, https, tcp-forwarding, ...]>
@@ -1348,6 +1367,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_accessproxy': {
             'type': 'dict',
             'v_range': [['7.0.0', '']],
@@ -1393,7 +1413,8 @@ def main():
                                 'type': {'v_range': [['7.0.1', '']], 'choices': ['tcp-forwarding', 'ssh'], 'type': 'str'},
                                 'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                                 'external-auth': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                                'verify-cert': {'v_range': [['7.4.8', '7.4.8'], ['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
@@ -1569,7 +1590,8 @@ def main():
                                 'weight': {'v_range': [['7.0.1', '']], 'type': 'int'},
                                 'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                                 'external-auth': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                                'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                                'verify-cert': {'v_range': [['7.4.8', '7.4.8'], ['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                             },
                             'elements': 'dict'
                         },
