@@ -16,7 +16,6 @@ short_description: Firewall casb profile saas application access rule
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.3.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -128,6 +130,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -136,8 +139,8 @@ EXAMPLES = '''
     - name: Firewall casb profile saas application access rule
       fortinet.fortimanager.fmgr_firewall_casbprofile_saasapplication_accessrule:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -213,6 +216,7 @@ def main():
         'casb_profile': {'type': 'str'},
         'saas-application': {'type': 'str', 'api_name': 'saas_application'},
         'saas_application': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_casbprofile_saasapplication_accessrule': {
             'type': 'dict',
             'v_range': [['7.4.1', '7.4.1']],
