@@ -16,7 +16,6 @@ short_description: Configure virtual IP for IPv6.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -96,83 +98,95 @@ options:
             _scope:
                 type: list
                 elements: dict
-                description: No description.
+                description: Scope.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
-            arp-reply:
+                        description: Vdom.
+            arp_reply:
+                aliases: ['arp-reply']
                 type: str
-                description: Deprecated, please rename it to arp_reply.
+                description: Arp reply.
                 choices:
                     - 'disable'
                     - 'enable'
             color:
                 type: int
-                description: No description.
+                description: Color.
             comment:
                 type: str
-                description: No description.
+                description: Comment.
             extip:
                 type: str
-                description: No description.
+                description: Extip.
             extport:
                 type: str
-                description: No description.
-            http-cookie-age:
+                description: Extport.
+            http_cookie_age:
+                aliases: ['http-cookie-age']
                 type: int
-                description: Deprecated, please rename it to http_cookie_age.
-            http-cookie-domain:
+                description: Http cookie age.
+            http_cookie_domain:
+                aliases: ['http-cookie-domain']
                 type: str
-                description: Deprecated, please rename it to http_cookie_domain.
-            http-cookie-domain-from-host:
+                description: Http cookie domain.
+            http_cookie_domain_from_host:
+                aliases: ['http-cookie-domain-from-host']
                 type: str
-                description: Deprecated, please rename it to http_cookie_domain_from_host.
+                description: Http cookie domain from host.
                 choices:
                     - 'disable'
                     - 'enable'
-            http-cookie-generation:
+            http_cookie_generation:
+                aliases: ['http-cookie-generation']
                 type: int
-                description: Deprecated, please rename it to http_cookie_generation.
-            http-cookie-path:
+                description: Http cookie generation.
+            http_cookie_path:
+                aliases: ['http-cookie-path']
                 type: str
-                description: Deprecated, please rename it to http_cookie_path.
-            http-cookie-share:
+                description: Http cookie path.
+            http_cookie_share:
+                aliases: ['http-cookie-share']
                 type: str
-                description: Deprecated, please rename it to http_cookie_share.
+                description: Http cookie share.
                 choices:
                     - 'disable'
                     - 'same-ip'
-            http-ip-header:
+            http_ip_header:
+                aliases: ['http-ip-header']
                 type: str
-                description: Deprecated, please rename it to http_ip_header.
+                description: Http ip header.
                 choices:
                     - 'disable'
                     - 'enable'
-            http-ip-header-name:
+            http_ip_header_name:
+                aliases: ['http-ip-header-name']
                 type: str
-                description: Deprecated, please rename it to http_ip_header_name.
-            http-multiplex:
+                description: Http ip header name.
+            http_multiplex:
+                aliases: ['http-multiplex']
                 type: str
-                description: Deprecated, please rename it to http_multiplex.
+                description: Http multiplex.
                 choices:
                     - 'disable'
                     - 'enable'
-            https-cookie-secure:
+            https_cookie_secure:
+                aliases: ['https-cookie-secure']
                 type: str
-                description: Deprecated, please rename it to https_cookie_secure.
+                description: Https cookie secure.
                 choices:
                     - 'disable'
                     - 'enable'
             id:
                 type: int
-                description: No description.
-            ldb-method:
+                description: Id.
+            ldb_method:
+                aliases: ['ldb-method']
                 type: str
-                description: Deprecated, please rename it to ldb_method.
+                description: Ldb method.
                 choices:
                     - 'static'
                     - 'round-robin'
@@ -183,45 +197,48 @@ options:
                     - 'http-host'
             mappedip:
                 type: str
-                description: No description.
+                description: Mappedip.
             mappedport:
                 type: str
-                description: No description.
-            max-embryonic-connections:
+                description: Mappedport.
+            max_embryonic_connections:
+                aliases: ['max-embryonic-connections']
                 type: int
-                description: Deprecated, please rename it to max_embryonic_connections.
+                description: Max embryonic connections.
             monitor:
                 type: raw
-                description: (list or str) No description.
-            outlook-web-access:
+                description: (list or str) Monitor.
+            outlook_web_access:
+                aliases: ['outlook-web-access']
                 type: str
-                description: Deprecated, please rename it to outlook_web_access.
+                description: Outlook web access.
                 choices:
                     - 'disable'
                     - 'enable'
             persistence:
                 type: str
-                description: No description.
+                description: Persistence.
                 choices:
                     - 'none'
                     - 'http-cookie'
                     - 'ssl-session-id'
             portforward:
                 type: str
-                description: No description.
+                description: Portforward.
                 choices:
                     - 'disable'
                     - 'enable'
             protocol:
                 type: str
-                description: No description.
+                description: Protocol.
                 choices:
                     - 'tcp'
                     - 'udp'
                     - 'sctp'
-            server-type:
+            server_type:
+                aliases: ['server-type']
                 type: str
-                description: Deprecated, please rename it to server_type.
+                description: Server type.
                 choices:
                     - 'http'
                     - 'https'
@@ -232,50 +249,59 @@ options:
                     - 'imaps'
                     - 'pop3s'
                     - 'smtps'
-            src-filter:
+            src_filter:
+                aliases: ['src-filter']
                 type: raw
-                description: (list) Deprecated, please rename it to src_filter.
-            ssl-algorithm:
+                description: (list) Src filter.
+            ssl_algorithm:
+                aliases: ['ssl-algorithm']
                 type: str
-                description: Deprecated, please rename it to ssl_algorithm.
+                description: Ssl algorithm.
                 choices:
                     - 'high'
                     - 'low'
                     - 'medium'
                     - 'custom'
-            ssl-certificate:
+            ssl_certificate:
+                aliases: ['ssl-certificate']
                 type: str
-                description: Deprecated, please rename it to ssl_certificate.
-            ssl-client-fallback:
+                description: Ssl certificate.
+            ssl_client_fallback:
+                aliases: ['ssl-client-fallback']
                 type: str
-                description: Deprecated, please rename it to ssl_client_fallback.
+                description: Ssl client fallback.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-client-renegotiation:
+            ssl_client_renegotiation:
+                aliases: ['ssl-client-renegotiation']
                 type: str
-                description: Deprecated, please rename it to ssl_client_renegotiation.
+                description: Ssl client renegotiation.
                 choices:
                     - 'deny'
                     - 'allow'
                     - 'secure'
-            ssl-client-session-state-max:
+            ssl_client_session_state_max:
+                aliases: ['ssl-client-session-state-max']
                 type: int
-                description: Deprecated, please rename it to ssl_client_session_state_max.
-            ssl-client-session-state-timeout:
+                description: Ssl client session state max.
+            ssl_client_session_state_timeout:
+                aliases: ['ssl-client-session-state-timeout']
                 type: int
-                description: Deprecated, please rename it to ssl_client_session_state_timeout.
-            ssl-client-session-state-type:
+                description: Ssl client session state timeout.
+            ssl_client_session_state_type:
+                aliases: ['ssl-client-session-state-type']
                 type: str
-                description: Deprecated, please rename it to ssl_client_session_state_type.
+                description: Ssl client session state type.
                 choices:
                     - 'disable'
                     - 'time'
                     - 'count'
                     - 'both'
-            ssl-dh-bits:
+            ssl_dh_bits:
+                aliases: ['ssl-dh-bits']
                 type: str
-                description: Deprecated, please rename it to ssl_dh_bits.
+                description: Ssl dh bits.
                 choices:
                     - '768'
                     - '1024'
@@ -283,107 +309,125 @@ options:
                     - '2048'
                     - '3072'
                     - '4096'
-            ssl-hpkp:
+            ssl_hpkp:
+                aliases: ['ssl-hpkp']
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp.
+                description: Ssl hpkp.
                 choices:
                     - 'disable'
                     - 'enable'
                     - 'report-only'
-            ssl-hpkp-age:
+            ssl_hpkp_age:
+                aliases: ['ssl-hpkp-age']
                 type: int
-                description: Deprecated, please rename it to ssl_hpkp_age.
-            ssl-hpkp-backup:
+                description: Ssl hpkp age.
+            ssl_hpkp_backup:
+                aliases: ['ssl-hpkp-backup']
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_backup.
-            ssl-hpkp-include-subdomains:
+                description: Ssl hpkp backup.
+            ssl_hpkp_include_subdomains:
+                aliases: ['ssl-hpkp-include-subdomains']
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_include_subdomains.
+                description: Ssl hpkp include subdomains.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-hpkp-primary:
+            ssl_hpkp_primary:
+                aliases: ['ssl-hpkp-primary']
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_primary.
-            ssl-hpkp-report-uri:
+                description: Ssl hpkp primary.
+            ssl_hpkp_report_uri:
+                aliases: ['ssl-hpkp-report-uri']
                 type: str
-                description: Deprecated, please rename it to ssl_hpkp_report_uri.
-            ssl-hsts:
+                description: Ssl hpkp report uri.
+            ssl_hsts:
+                aliases: ['ssl-hsts']
                 type: str
-                description: Deprecated, please rename it to ssl_hsts.
+                description: Ssl hsts.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-hsts-age:
+            ssl_hsts_age:
+                aliases: ['ssl-hsts-age']
                 type: int
-                description: Deprecated, please rename it to ssl_hsts_age.
-            ssl-hsts-include-subdomains:
+                description: Ssl hsts age.
+            ssl_hsts_include_subdomains:
+                aliases: ['ssl-hsts-include-subdomains']
                 type: str
-                description: Deprecated, please rename it to ssl_hsts_include_subdomains.
+                description: Ssl hsts include subdomains.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-http-location-conversion:
+            ssl_http_location_conversion:
+                aliases: ['ssl-http-location-conversion']
                 type: str
-                description: Deprecated, please rename it to ssl_http_location_conversion.
+                description: Ssl http location conversion.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-http-match-host:
+            ssl_http_match_host:
+                aliases: ['ssl-http-match-host']
                 type: str
-                description: Deprecated, please rename it to ssl_http_match_host.
+                description: Ssl http match host.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-max-version:
+            ssl_max_version:
+                aliases: ['ssl-max-version']
                 type: str
-                description: Deprecated, please rename it to ssl_max_version.
+                description: Ssl max version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
                     - 'tls-1.1'
                     - 'tls-1.2'
                     - 'tls-1.3'
-            ssl-min-version:
+            ssl_min_version:
+                aliases: ['ssl-min-version']
                 type: str
-                description: Deprecated, please rename it to ssl_min_version.
+                description: Ssl min version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
                     - 'tls-1.1'
                     - 'tls-1.2'
                     - 'tls-1.3'
-            ssl-mode:
+            ssl_mode:
+                aliases: ['ssl-mode']
                 type: str
-                description: Deprecated, please rename it to ssl_mode.
+                description: Ssl mode.
                 choices:
                     - 'half'
                     - 'full'
-            ssl-pfs:
+            ssl_pfs:
+                aliases: ['ssl-pfs']
                 type: str
-                description: Deprecated, please rename it to ssl_pfs.
+                description: Ssl pfs.
                 choices:
                     - 'require'
                     - 'deny'
                     - 'allow'
-            ssl-send-empty-frags:
+            ssl_send_empty_frags:
+                aliases: ['ssl-send-empty-frags']
                 type: str
-                description: Deprecated, please rename it to ssl_send_empty_frags.
+                description: Ssl send empty frags.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-server-algorithm:
+            ssl_server_algorithm:
+                aliases: ['ssl-server-algorithm']
                 type: str
-                description: Deprecated, please rename it to ssl_server_algorithm.
+                description: Ssl server algorithm.
                 choices:
                     - 'high'
                     - 'low'
                     - 'medium'
                     - 'custom'
                     - 'client'
-            ssl-server-max-version:
+            ssl_server_max_version:
+                aliases: ['ssl-server-max-version']
                 type: str
-                description: Deprecated, please rename it to ssl_server_max_version.
+                description: Ssl server max version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -391,9 +435,10 @@ options:
                     - 'tls-1.2'
                     - 'client'
                     - 'tls-1.3'
-            ssl-server-min-version:
+            ssl_server_min_version:
+                aliases: ['ssl-server-min-version']
                 type: str
-                description: Deprecated, please rename it to ssl_server_min_version.
+                description: Ssl server min version.
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -401,15 +446,18 @@ options:
                     - 'tls-1.2'
                     - 'client'
                     - 'tls-1.3'
-            ssl-server-session-state-max:
+            ssl_server_session_state_max:
+                aliases: ['ssl-server-session-state-max']
                 type: int
-                description: Deprecated, please rename it to ssl_server_session_state_max.
-            ssl-server-session-state-timeout:
+                description: Ssl server session state max.
+            ssl_server_session_state_timeout:
+                aliases: ['ssl-server-session-state-timeout']
                 type: int
-                description: Deprecated, please rename it to ssl_server_session_state_timeout.
-            ssl-server-session-state-type:
+                description: Ssl server session state timeout.
+            ssl_server_session_state_type:
+                aliases: ['ssl-server-session-state-type']
                 type: str
-                description: Deprecated, please rename it to ssl_server_session_state_type.
+                description: Ssl server session state type.
                 choices:
                     - 'disable'
                     - 'time'
@@ -417,59 +465,68 @@ options:
                     - 'both'
             type:
                 type: str
-                description: No description.
+                description: Type.
                 choices:
                     - 'static-nat'
                     - 'server-load-balance'
                     - 'access-proxy'
             uuid:
                 type: str
-                description: No description.
-            weblogic-server:
+                description: Uuid.
+            weblogic_server:
+                aliases: ['weblogic-server']
                 type: str
-                description: Deprecated, please rename it to weblogic_server.
+                description: Weblogic server.
                 choices:
                     - 'disable'
                     - 'enable'
-            websphere-server:
+            websphere_server:
+                aliases: ['websphere-server']
                 type: str
-                description: Deprecated, please rename it to websphere_server.
+                description: Websphere server.
                 choices:
                     - 'disable'
                     - 'enable'
-            http-redirect:
+            http_redirect:
+                aliases: ['http-redirect']
                 type: str
-                description: Deprecated, please rename it to http_redirect.
+                description: Http redirect.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-client-rekey-count:
+            ssl_client_rekey_count:
+                aliases: ['ssl-client-rekey-count']
                 type: int
-                description: Deprecated, please rename it to ssl_client_rekey_count.
-            nat-source-vip:
+                description: Ssl client rekey count.
+            nat_source_vip:
+                aliases: ['nat-source-vip']
                 type: str
-                description: Deprecated, please rename it to nat_source_vip.
+                description: Nat source vip.
                 choices:
                     - 'disable'
                     - 'enable'
-            add-nat64-route:
+            add_nat64_route:
+                aliases: ['add-nat64-route']
                 type: str
-                description: Deprecated, please rename it to add_nat64_route. Enable/disable adding NAT64 route.
+                description: Enable/disable adding NAT64 route.
                 choices:
                     - 'disable'
                     - 'enable'
-            embedded-ipv4-address:
+            embedded_ipv4_address:
+                aliases: ['embedded-ipv4-address']
                 type: str
-                description: Deprecated, please rename it to embedded_ipv4_address. Enable/disable use of the lower 32 bits of the external IPv6 addres...
+                description: Enable/disable use of the lower 32 bits of the external IPv6 address as mapped IPv4 address.
                 choices:
                     - 'disable'
                     - 'enable'
-            ipv4-mappedip:
+            ipv4_mappedip:
+                aliases: ['ipv4-mappedip']
                 type: str
-                description: Deprecated, please rename it to ipv4_mappedip. Range of mapped IP addresses.
-            ipv4-mappedport:
+                description: Range of mapped IP addresses.
+            ipv4_mappedport:
+                aliases: ['ipv4-mappedport']
                 type: str
-                description: Deprecated, please rename it to ipv4_mappedport. IPv4 port number range on the destination network to which the external p...
+                description: IPv4 port number range on the destination network to which the external port number range is mapped.
             nat64:
                 type: str
                 description: Enable/disable DNAT64.
@@ -485,11 +542,12 @@ options:
             realservers:
                 type: list
                 elements: dict
-                description: No description.
+                description: Realservers.
                 suboptions:
-                    client-ip:
+                    client_ip:
+                        aliases: ['client-ip']
                         type: str
-                        description: Deprecated, please rename it to client_ip. Only clients in this IP range can connect to this real server.
+                        description: Only clients in this IP range can connect to this real server.
                     healthcheck:
                         type: str
                         description: Enable to check the responsiveness of the real server before forwarding traffic.
@@ -497,24 +555,27 @@ options:
                             - 'disable'
                             - 'enable'
                             - 'vip'
-                    holddown-interval:
+                    holddown_interval:
+                        aliases: ['holddown-interval']
                         type: int
-                        description: Deprecated, please rename it to holddown_interval. Time in seconds that the health check monitor continues to moni...
-                    http-host:
+                        description: Time in seconds that the health check monitor continues to monitor an unresponsive server that should be active.
+                    http_host:
+                        aliases: ['http-host']
                         type: str
-                        description: Deprecated, please rename it to http_host. HTTP server domain name in HTTP header.
+                        description: HTTP server domain name in HTTP header.
                     id:
                         type: int
                         description: Real server ID.
                     ip:
                         type: str
                         description: IP address of the real server.
-                    max-connections:
+                    max_connections:
+                        aliases: ['max-connections']
                         type: int
-                        description: Deprecated, please rename it to max_connections. Max number of active connections that can directed to the real se...
+                        description: Max number of active connections that can directed to the real server.
                     monitor:
                         type: raw
-                        description: (list or str) No description.
+                        description: (list or str) Name of the health check monitor to use when polling to determine a virtual servers connectivity status.
                     port:
                         type: int
                         description: Port for communicating with the real server.
@@ -528,22 +589,32 @@ options:
                     weight:
                         type: int
                         description: Weight of the real server.
-                    translate-host:
+                    translate_host:
+                        aliases: ['translate-host']
                         type: str
-                        description: Deprecated, please rename it to translate_host. Enable/disable translation of hostname/IP from virtual server to r...
+                        description: Enable/disable translation of hostname/IP from virtual server to real server.
                         choices:
                             - 'disable'
                             - 'enable'
-            ssl-accept-ffdhe-groups:
+                    verify_cert:
+                        aliases: ['verify-cert']
+                        type: str
+                        description: Enable/disable certificate verification of the real server.
+                        choices:
+                            - 'disable'
+                            - 'enable'
+            ssl_accept_ffdhe_groups:
+                aliases: ['ssl-accept-ffdhe-groups']
                 type: str
-                description: Deprecated, please rename it to ssl_accept_ffdhe_groups. Enable/disable FFDHE cipher suite for SSL key exchange.
+                description: Enable/disable FFDHE cipher suite for SSL key exchange.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-cipher-suites:
+            ssl_cipher_suites:
+                aliases: ['ssl-cipher-suites']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ssl_cipher_suites.
+                description: Ssl cipher suites.
                 suboptions:
                     cipher:
                         type: str
@@ -626,34 +697,67 @@ options:
                     versions:
                         type: list
                         elements: str
-                        description: No description.
+                        description: SSL/TLS versions that the cipher suite can be used with.
                         choices:
                             - 'ssl-3.0'
                             - 'tls-1.0'
                             - 'tls-1.1'
                             - 'tls-1.2'
                             - 'tls-1.3'
-            ndp-reply:
+            ndp_reply:
+                aliases: ['ndp-reply']
                 type: str
-                description: Deprecated, please rename it to ndp_reply. Enable/disable this FortiGate units ability to respond to NDP requests for this...
+                description: Enable/disable this FortiGate units ability to respond to NDP requests for this virtual IP address
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-server-renegotiation:
+            ssl_server_renegotiation:
+                aliases: ['ssl-server-renegotiation']
                 type: str
-                description: Deprecated, please rename it to ssl_server_renegotiation. Enable/disable secure renegotiation to comply with RFC 5746.
+                description: Enable/disable secure renegotiation to comply with RFC 5746.
                 choices:
                     - 'disable'
                     - 'enable'
-            h2-support:
+            h2_support:
+                aliases: ['h2-support']
                 type: str
-                description: Deprecated, please rename it to h2_support. Enable/disable HTTP2 support
+                description: Enable/disable HTTP2 support
                 choices:
                     - 'disable'
                     - 'enable'
-            h3-support:
+            h3_support:
+                aliases: ['h3-support']
                 type: str
-                description: Deprecated, please rename it to h3_support. Enable/disable HTTP3/QUIC support
+                description: Enable/disable HTTP3/QUIC support
+                choices:
+                    - 'disable'
+                    - 'enable'
+            src_vip_filter:
+                aliases: ['src-vip-filter']
+                type: str
+                description: Enable/disable use of src-filter to match destinations for the reverse SNAT rule.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            client_cert:
+                aliases: ['client-cert']
+                type: str
+                description: Enable/disable requesting client certificate.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            empty_cert_action:
+                aliases: ['empty-cert-action']
+                type: str
+                description: Action for an empty client certificate.
+                choices:
+                    - 'accept'
+                    - 'block'
+                    - 'accept-unmanageable'
+            user_agent_detect:
+                aliases: ['user-agent-detect']
+                type: str
+                description: Enable/disable detecting device type by HTTP user-agent if no client certificate is provided.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -662,6 +766,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -678,7 +783,7 @@ EXAMPLES = '''
           _scope:
             - name: FGT_AWS # need a valid device name
               vdom: root # need a valid vdom name under the device
-          arp-reply: disable
+          arp_reply: disable
           color: 1
           comment: "ansible-comment"
           id: 1
@@ -743,28 +848,21 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/vip6/{vip6}/dynamic_mapping',
         '/pm/config/global/obj/firewall/vip6/{vip6}/dynamic_mapping'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/vip6/{vip6}/dynamic_mapping/{dynamic_mapping}',
-        '/pm/config/global/obj/firewall/vip6/{vip6}/dynamic_mapping/{dynamic_mapping}'
-    ]
-
     url_params = ['adom', 'vip6']
     module_primary_key = 'complex:{{module}}["_scope"][0]["name"]+"/"+{{module}}["_scope"][0]["vdom"]'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'vip6': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_vip6_dynamicmapping': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -855,7 +953,8 @@ def main():
                         'port': {'v_range': [['7.0.2', '']], 'type': 'int'},
                         'status': {'v_range': [['7.0.2', '']], 'choices': ['active', 'standby', 'disable'], 'type': 'str'},
                         'weight': {'v_range': [['7.0.2', '']], 'type': 'int'},
-                        'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'verify-cert': {'v_range': [['7.6.4', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
@@ -906,12 +1005,15 @@ def main():
                     },
                     'elements': 'dict'
                 },
-                'ndp-reply': {'v_range': [['7.0.5', '7.0.12'], ['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ndp-reply': {'v_range': [['7.0.5', '7.0.15'], ['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'ssl-server-renegotiation': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'h2-support': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'h3-support': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'h3-support': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'src-vip-filter': {'v_range': [['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'client-cert': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'empty-cert-action': {'v_range': [['7.6.2', '']], 'choices': ['accept', 'block', 'accept-unmanageable'], 'type': 'str'},
+                'user-agent-detect': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -920,17 +1022,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_vip6_dynamicmapping'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
