@@ -16,7 +16,6 @@ short_description: OSU service name.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -98,12 +100,14 @@ options:
             lang:
                 type: str
                 description: Language code.
-            service-description:
+            service_description:
+                aliases: ['service-description']
                 type: str
-                description: Deprecated, please rename it to service_description. Service description.
-            service-id:
+                description: Service description.
+            service_id:
+                aliases: ['service-id']
                 type: int
-                description: Deprecated, please rename it to service_id. OSU service ID.
+                description: OSU service ID.
                 required: true
 '''
 
@@ -111,6 +115,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -119,17 +124,17 @@ EXAMPLES = '''
     - name: OSU service name.
       fortinet.fortimanager.fmgr_hotspot20_h2qposuprovider_servicedescription:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         h2qp_osu_provider: <your own value>
         state: present # <value in [present, absent]>
         hotspot20_h2qposuprovider_servicedescription:
-          lang: <string>
-          service_description: <string>
-          service_id: <integer>
+          service_id: 0 # Required variable, integer
+          # lang: <string>
+          # service_description: <string>
 '''
 
 RETURN = '''
@@ -173,34 +178,26 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/wireless-controller/hotspot20/h2qp-osu-provider/{h2qp-osu-provider}/service-description',
         '/pm/config/global/obj/wireless-controller/hotspot20/h2qp-osu-provider/{h2qp-osu-provider}/service-description'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/wireless-controller/hotspot20/h2qp-osu-provider/{h2qp-osu-provider}/service-description/{service-description}',
-        '/pm/config/global/obj/wireless-controller/hotspot20/h2qp-osu-provider/{h2qp-osu-provider}/service-description/{service-description}'
-    ]
-
     url_params = ['adom', 'h2qp-osu-provider']
     module_primary_key = 'service-id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'h2qp-osu-provider': {'type': 'str', 'api_name': 'h2qp_osu_provider'},
         'h2qp_osu_provider': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'hotspot20_h2qposuprovider_servicedescription': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'lang': {'type': 'str'}, 'service-description': {'type': 'str'}, 'service-id': {'required': True, 'type': 'int'}}
-
         }
     }
 
@@ -209,17 +206,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'hotspot20_h2qposuprovider_servicedescription'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
