@@ -16,7 +16,6 @@ short_description: Configure IPS sensor.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "1.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -554,7 +553,7 @@ def main():
                         'rule': {'type': 'raw'},
                         'severity': {'type': 'raw'},
                         'status': {'choices': ['disable', 'enable', 'default'], 'type': 'str'},
-                        'tags': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'},
+                        'tags': {'v_range': [['6.2.0', '6.4.15'], ['7.4.8', '7.4.8']], 'type': 'str'},
                         'cve': {'v_range': [['6.4.2', '']], 'type': 'raw'},
                         'default-action': {'v_range': [['7.2.0', '']], 'choices': ['block', 'pass', 'all', 'drop'], 'type': 'str'},
                         'default-status': {'v_range': [['7.2.0', '']], 'choices': ['disable', 'enable', 'all'], 'type': 'str'},
