@@ -16,7 +16,6 @@ short_description: Anomaly name.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -311,6 +313,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -322,7 +325,7 @@ EXAMPLES = '''
         bypass_validation: false
         adom: ansible
         pkg: ansible # package name
-        DoS-policy6: 1 # policyid
+        DoS_policy6: 1 # policyid
         state: present
         pkg_firewall_dospolicy6_anomaly:
           action: pass # <value in [pass, block, proxy]>
@@ -347,7 +350,7 @@ EXAMPLES = '''
           params:
             adom: "ansible"
             pkg: "ansible" # package name
-            DoS-policy6: "1" # policyid
+            DoS_policy6: "1" # policyid
             anomaly: "your_value"
 '''
 
@@ -407,6 +410,7 @@ def main():
         'pkg': {'required': True, 'type': 'str'},
         'DoS-policy6': {'type': 'str', 'api_name': 'DoS_policy6'},
         'DoS_policy6': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_firewall_dospolicy6_anomaly': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -440,37 +444,37 @@ def main():
                     'type': 'str'
                 },
                 'synproxy-tos': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['0', '10', '12', '14', '18', '20', '22', '26', '28', '30', '34', '36', '38', '40', '46', '255'],
                     'type': 'str'
                 },
                 'synproxy-tcp-window': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['4096', '8192', '16384', '32768'],
                     'type': 'str'
                 },
                 'synproxy-tcp-windowscale': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14'],
                     'type': 'str'
                 },
                 'synproxy-tcp-timestamp': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['disable', 'enable'],
                     'type': 'str'
                 },
                 'synproxy-ttl': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['32', '64', '128', '255'],
                     'type': 'str'
                 },
                 'synproxy-tcp-mss': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['0', '256', '512', '1024', '1300', '1360', '1460', '1500'],
                     'type': 'str'
                 },
                 'synproxy-tcp-sack': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['disable', 'enable'],
                     'type': 'str'
                 }
