@@ -16,7 +16,6 @@ short_description: System template adom
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -126,6 +125,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -137,7 +137,7 @@ EXAMPLES = '''
         adom: ansible
         pm_devprof_adom:
           description: "ansible-test"
-          enabled options:
+          enabled_options:
             - none
             - dns
             - ntp
