@@ -16,7 +16,6 @@ short_description: MSN Hotmail.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -64,6 +63,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -96,6 +98,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -104,14 +107,14 @@ EXAMPLES = '''
     - name: MSN Hotmail.
       fortinet.fortimanager.fmgr_spamfilter_profile_msnhotmail:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         spamfilter_profile_msnhotmail:
-          log: <value in [disable, enable]>
+          # log: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -169,10 +172,11 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'spamfilter_profile_msnhotmail': {
             'type': 'dict',
-            'v_range': [['6.0.0', '7.2.1']],
-            'options': {'log': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'}}
+            'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']],
+            'options': {'log': {'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']], 'choices': ['disable', 'enable'], 'type': 'str'}}
         }
     }
 
