@@ -16,7 +16,6 @@ short_description: Filter for memory logging.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -469,6 +468,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -477,54 +477,54 @@ EXAMPLES = '''
     - name: Filter for memory logging.
       fortinet.fortimanager.fmgr_system_locallog_memory_filter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_locallog_memory_filter:
-          devcfg: <value in [disable, enable]>
-          devops: <value in [disable, enable]>
-          diskquota: <value in [disable, enable]>
-          dm: <value in [disable, enable]>
-          dvm: <value in [disable, enable]>
-          ediscovery: <value in [disable, enable]>
-          epmgr: <value in [disable, enable]>
-          event: <value in [disable, enable]>
-          eventmgmt: <value in [disable, enable]>
-          faz: <value in [disable, enable]>
-          fazha: <value in [disable, enable]>
-          fazsys: <value in [disable, enable]>
-          fgd: <value in [disable, enable]>
-          fgfm: <value in [disable, enable]>
-          fips: <value in [disable, enable]>
-          fmgws: <value in [disable, enable]>
-          fmlmgr: <value in [disable, enable]>
-          fmwmgr: <value in [disable, enable]>
-          fortiview: <value in [disable, enable]>
-          glbcfg: <value in [disable, enable]>
-          ha: <value in [disable, enable]>
-          hcache: <value in [disable, enable]>
-          iolog: <value in [disable, enable]>
-          logd: <value in [disable, enable]>
-          logdb: <value in [disable, enable]>
-          logdev: <value in [disable, enable]>
-          logfile: <value in [enable, disable]>
-          logging: <value in [disable, enable]>
-          lrmgr: <value in [disable, enable]>
-          objcfg: <value in [disable, enable]>
-          report: <value in [disable, enable]>
-          rev: <value in [disable, enable]>
-          rtmon: <value in [disable, enable]>
-          scfw: <value in [disable, enable]>
-          scply: <value in [disable, enable]>
-          scrmgr: <value in [disable, enable]>
-          scvpn: <value in [disable, enable]>
-          system: <value in [disable, enable]>
-          webport: <value in [disable, enable]>
-          incident: <value in [disable, enable]>
-          aid: <value in [disable, enable]>
-          docker: <value in [disable, enable]>
-          controller: <value in [disable, enable]>
+          # devcfg: <value in [disable, enable]>
+          # devops: <value in [disable, enable]>
+          # diskquota: <value in [disable, enable]>
+          # dm: <value in [disable, enable]>
+          # dvm: <value in [disable, enable]>
+          # ediscovery: <value in [disable, enable]>
+          # epmgr: <value in [disable, enable]>
+          # event: <value in [disable, enable]>
+          # eventmgmt: <value in [disable, enable]>
+          # faz: <value in [disable, enable]>
+          # fazha: <value in [disable, enable]>
+          # fazsys: <value in [disable, enable]>
+          # fgd: <value in [disable, enable]>
+          # fgfm: <value in [disable, enable]>
+          # fips: <value in [disable, enable]>
+          # fmgws: <value in [disable, enable]>
+          # fmlmgr: <value in [disable, enable]>
+          # fmwmgr: <value in [disable, enable]>
+          # fortiview: <value in [disable, enable]>
+          # glbcfg: <value in [disable, enable]>
+          # ha: <value in [disable, enable]>
+          # hcache: <value in [disable, enable]>
+          # iolog: <value in [disable, enable]>
+          # logd: <value in [disable, enable]>
+          # logdb: <value in [disable, enable]>
+          # logdev: <value in [disable, enable]>
+          # logfile: <value in [enable, disable]>
+          # logging: <value in [disable, enable]>
+          # lrmgr: <value in [disable, enable]>
+          # objcfg: <value in [disable, enable]>
+          # report: <value in [disable, enable]>
+          # rev: <value in [disable, enable]>
+          # rtmon: <value in [disable, enable]>
+          # scfw: <value in [disable, enable]>
+          # scply: <value in [disable, enable]>
+          # scrmgr: <value in [disable, enable]>
+          # scvpn: <value in [disable, enable]>
+          # system: <value in [disable, enable]>
+          # webport: <value in [disable, enable]>
+          # incident: <value in [disable, enable]>
+          # aid: <value in [disable, enable]>
+          # docker: <value in [disable, enable]>
+          # controller: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -623,9 +623,13 @@ def main():
                 'system': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'webport': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'incident': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'aid': {'v_range': [['6.4.1', '7.2.9']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'docker': {'v_range': [['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'controller': {'v_range': [['7.0.9', '7.0.13'], ['7.2.4', '7.2.9'], ['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'aid': {'v_range': [['6.4.1', '7.2.11']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'docker': {
+                    'v_range': [['6.4.3', '7.0.14'], ['7.2.0', '7.2.10'], ['7.4.0', '7.4.7'], ['7.6.0', '7.6.3']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'controller': {'v_range': [['7.0.9', '7.0.15'], ['7.2.4', '7.2.11'], ['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
