@@ -16,7 +16,6 @@ short_description: Configure a NP7 class profile.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.2.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -972,6 +974,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -980,88 +983,88 @@ EXAMPLES = '''
     - name: Configure a NP7 class profile.
       fortinet.fortimanager.fmgr_system_npu_npqueues_profile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         system_npu_npqueues_profile:
-          cos0: <value in [queue0, queue1, queue2, ...]>
-          cos1: <value in [queue0, queue1, queue2, ...]>
-          cos2: <value in [queue0, queue1, queue2, ...]>
-          cos3: <value in [queue0, queue1, queue2, ...]>
-          cos4: <value in [queue0, queue1, queue2, ...]>
-          cos5: <value in [queue0, queue1, queue2, ...]>
-          cos6: <value in [queue0, queue1, queue2, ...]>
-          cos7: <value in [queue0, queue1, queue2, ...]>
-          dscp0: <value in [queue0, queue1, queue2, ...]>
-          dscp1: <value in [queue0, queue1, queue2, ...]>
-          dscp10: <value in [queue0, queue1, queue2, ...]>
-          dscp11: <value in [queue0, queue1, queue2, ...]>
-          dscp12: <value in [queue0, queue1, queue2, ...]>
-          dscp13: <value in [queue0, queue1, queue2, ...]>
-          dscp14: <value in [queue0, queue1, queue2, ...]>
-          dscp15: <value in [queue0, queue1, queue2, ...]>
-          dscp16: <value in [queue0, queue1, queue2, ...]>
-          dscp17: <value in [queue0, queue1, queue2, ...]>
-          dscp18: <value in [queue0, queue1, queue2, ...]>
-          dscp19: <value in [queue0, queue1, queue2, ...]>
-          dscp2: <value in [queue0, queue1, queue2, ...]>
-          dscp20: <value in [queue0, queue1, queue2, ...]>
-          dscp21: <value in [queue0, queue1, queue2, ...]>
-          dscp22: <value in [queue0, queue1, queue2, ...]>
-          dscp23: <value in [queue0, queue1, queue2, ...]>
-          dscp24: <value in [queue0, queue1, queue2, ...]>
-          dscp25: <value in [queue0, queue1, queue2, ...]>
-          dscp26: <value in [queue0, queue1, queue2, ...]>
-          dscp27: <value in [queue0, queue1, queue2, ...]>
-          dscp28: <value in [queue0, queue1, queue2, ...]>
-          dscp29: <value in [queue0, queue1, queue2, ...]>
-          dscp3: <value in [queue0, queue1, queue2, ...]>
-          dscp30: <value in [queue0, queue1, queue2, ...]>
-          dscp31: <value in [queue0, queue1, queue2, ...]>
-          dscp32: <value in [queue0, queue1, queue2, ...]>
-          dscp33: <value in [queue0, queue1, queue2, ...]>
-          dscp34: <value in [queue0, queue1, queue2, ...]>
-          dscp35: <value in [queue0, queue1, queue2, ...]>
-          dscp36: <value in [queue0, queue1, queue2, ...]>
-          dscp37: <value in [queue0, queue1, queue2, ...]>
-          dscp38: <value in [queue0, queue1, queue2, ...]>
-          dscp39: <value in [queue0, queue1, queue2, ...]>
-          dscp4: <value in [queue0, queue1, queue2, ...]>
-          dscp40: <value in [queue0, queue1, queue2, ...]>
-          dscp41: <value in [queue0, queue1, queue2, ...]>
-          dscp42: <value in [queue0, queue1, queue2, ...]>
-          dscp43: <value in [queue0, queue1, queue2, ...]>
-          dscp44: <value in [queue0, queue1, queue2, ...]>
-          dscp45: <value in [queue0, queue1, queue2, ...]>
-          dscp46: <value in [queue0, queue1, queue2, ...]>
-          dscp47: <value in [queue0, queue1, queue2, ...]>
-          dscp48: <value in [queue0, queue1, queue2, ...]>
-          dscp49: <value in [queue0, queue1, queue2, ...]>
-          dscp5: <value in [queue0, queue1, queue2, ...]>
-          dscp50: <value in [queue0, queue1, queue2, ...]>
-          dscp51: <value in [queue0, queue1, queue2, ...]>
-          dscp52: <value in [queue0, queue1, queue2, ...]>
-          dscp53: <value in [queue0, queue1, queue2, ...]>
-          dscp54: <value in [queue0, queue1, queue2, ...]>
-          dscp55: <value in [queue0, queue1, queue2, ...]>
-          dscp56: <value in [queue0, queue1, queue2, ...]>
-          dscp57: <value in [queue0, queue1, queue2, ...]>
-          dscp58: <value in [queue0, queue1, queue2, ...]>
-          dscp59: <value in [queue0, queue1, queue2, ...]>
-          dscp6: <value in [queue0, queue1, queue2, ...]>
-          dscp60: <value in [queue0, queue1, queue2, ...]>
-          dscp61: <value in [queue0, queue1, queue2, ...]>
-          dscp62: <value in [queue0, queue1, queue2, ...]>
-          dscp63: <value in [queue0, queue1, queue2, ...]>
-          dscp7: <value in [queue0, queue1, queue2, ...]>
-          dscp8: <value in [queue0, queue1, queue2, ...]>
-          dscp9: <value in [queue0, queue1, queue2, ...]>
-          id: <integer>
-          type: <value in [cos, dscp]>
-          weight: <integer>
+          id: 0 # Required variable, integer
+          # cos0: <value in [queue0, queue1, queue2, ...]>
+          # cos1: <value in [queue0, queue1, queue2, ...]>
+          # cos2: <value in [queue0, queue1, queue2, ...]>
+          # cos3: <value in [queue0, queue1, queue2, ...]>
+          # cos4: <value in [queue0, queue1, queue2, ...]>
+          # cos5: <value in [queue0, queue1, queue2, ...]>
+          # cos6: <value in [queue0, queue1, queue2, ...]>
+          # cos7: <value in [queue0, queue1, queue2, ...]>
+          # dscp0: <value in [queue0, queue1, queue2, ...]>
+          # dscp1: <value in [queue0, queue1, queue2, ...]>
+          # dscp10: <value in [queue0, queue1, queue2, ...]>
+          # dscp11: <value in [queue0, queue1, queue2, ...]>
+          # dscp12: <value in [queue0, queue1, queue2, ...]>
+          # dscp13: <value in [queue0, queue1, queue2, ...]>
+          # dscp14: <value in [queue0, queue1, queue2, ...]>
+          # dscp15: <value in [queue0, queue1, queue2, ...]>
+          # dscp16: <value in [queue0, queue1, queue2, ...]>
+          # dscp17: <value in [queue0, queue1, queue2, ...]>
+          # dscp18: <value in [queue0, queue1, queue2, ...]>
+          # dscp19: <value in [queue0, queue1, queue2, ...]>
+          # dscp2: <value in [queue0, queue1, queue2, ...]>
+          # dscp20: <value in [queue0, queue1, queue2, ...]>
+          # dscp21: <value in [queue0, queue1, queue2, ...]>
+          # dscp22: <value in [queue0, queue1, queue2, ...]>
+          # dscp23: <value in [queue0, queue1, queue2, ...]>
+          # dscp24: <value in [queue0, queue1, queue2, ...]>
+          # dscp25: <value in [queue0, queue1, queue2, ...]>
+          # dscp26: <value in [queue0, queue1, queue2, ...]>
+          # dscp27: <value in [queue0, queue1, queue2, ...]>
+          # dscp28: <value in [queue0, queue1, queue2, ...]>
+          # dscp29: <value in [queue0, queue1, queue2, ...]>
+          # dscp3: <value in [queue0, queue1, queue2, ...]>
+          # dscp30: <value in [queue0, queue1, queue2, ...]>
+          # dscp31: <value in [queue0, queue1, queue2, ...]>
+          # dscp32: <value in [queue0, queue1, queue2, ...]>
+          # dscp33: <value in [queue0, queue1, queue2, ...]>
+          # dscp34: <value in [queue0, queue1, queue2, ...]>
+          # dscp35: <value in [queue0, queue1, queue2, ...]>
+          # dscp36: <value in [queue0, queue1, queue2, ...]>
+          # dscp37: <value in [queue0, queue1, queue2, ...]>
+          # dscp38: <value in [queue0, queue1, queue2, ...]>
+          # dscp39: <value in [queue0, queue1, queue2, ...]>
+          # dscp4: <value in [queue0, queue1, queue2, ...]>
+          # dscp40: <value in [queue0, queue1, queue2, ...]>
+          # dscp41: <value in [queue0, queue1, queue2, ...]>
+          # dscp42: <value in [queue0, queue1, queue2, ...]>
+          # dscp43: <value in [queue0, queue1, queue2, ...]>
+          # dscp44: <value in [queue0, queue1, queue2, ...]>
+          # dscp45: <value in [queue0, queue1, queue2, ...]>
+          # dscp46: <value in [queue0, queue1, queue2, ...]>
+          # dscp47: <value in [queue0, queue1, queue2, ...]>
+          # dscp48: <value in [queue0, queue1, queue2, ...]>
+          # dscp49: <value in [queue0, queue1, queue2, ...]>
+          # dscp5: <value in [queue0, queue1, queue2, ...]>
+          # dscp50: <value in [queue0, queue1, queue2, ...]>
+          # dscp51: <value in [queue0, queue1, queue2, ...]>
+          # dscp52: <value in [queue0, queue1, queue2, ...]>
+          # dscp53: <value in [queue0, queue1, queue2, ...]>
+          # dscp54: <value in [queue0, queue1, queue2, ...]>
+          # dscp55: <value in [queue0, queue1, queue2, ...]>
+          # dscp56: <value in [queue0, queue1, queue2, ...]>
+          # dscp57: <value in [queue0, queue1, queue2, ...]>
+          # dscp58: <value in [queue0, queue1, queue2, ...]>
+          # dscp59: <value in [queue0, queue1, queue2, ...]>
+          # dscp6: <value in [queue0, queue1, queue2, ...]>
+          # dscp60: <value in [queue0, queue1, queue2, ...]>
+          # dscp61: <value in [queue0, queue1, queue2, ...]>
+          # dscp62: <value in [queue0, queue1, queue2, ...]>
+          # dscp63: <value in [queue0, queue1, queue2, ...]>
+          # dscp7: <value in [queue0, queue1, queue2, ...]>
+          # dscp8: <value in [queue0, queue1, queue2, ...]>
+          # dscp9: <value in [queue0, queue1, queue2, ...]>
+          # type: <value in [cos, dscp]>
+          # weight: <integer>
 '''
 
 RETURN = '''
@@ -1105,396 +1108,388 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/npu/np-queues/profile',
         '/pm/config/global/obj/system/npu/np-queues/profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/npu/np-queues/profile/{profile}',
-        '/pm/config/global/obj/system/npu/np-queues/profile/{profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_npu_npqueues_profile': {
             'type': 'dict',
-            'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+            'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
             'options': {
                 'cos0': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos1': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos2': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos3': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos4': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos5': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos6': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'cos7': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp0': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp1': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp10': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp11': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp12': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp13': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp14': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp15': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp16': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp17': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp18': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp19': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp2': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp20': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp21': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp22': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp23': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp24': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp25': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp26': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp27': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp28': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp29': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp3': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp30': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp31': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp32': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp33': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp34': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp35': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp36': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp37': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp38': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp39': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp4': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp40': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp41': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp42': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp43': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp44': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp45': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp46': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp47': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp48': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp49': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp5': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp50': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp51': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp52': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp53': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp54': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp55': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp56': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp57': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp58': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp59': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp6': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp60': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp61': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp62': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp63': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp7': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp8': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
                 'dscp9': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'choices': ['queue0', 'queue1', 'queue2', 'queue3', 'queue4', 'queue5', 'queue6', 'queue7'],
                     'type': 'str'
                 },
-                'id': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'required': True, 'type': 'int'},
-                'type': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'choices': ['cos', 'dscp'], 'type': 'str'},
-                'weight': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'type': 'int'}
+                'id': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'required': True, 'type': 'int'},
+                'type': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'choices': ['cos', 'dscp'], 'type': 'str'},
+                'weight': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -1503,17 +1498,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_npu_npqueues_profile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
