@@ -16,7 +16,6 @@ short_description: SD-WAN status checking or health checking.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -284,6 +283,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -292,8 +292,8 @@ EXAMPLES = '''
     - name: SD-WAN status checking or health checking.
       fortinet.fortimanager.fmgr_wanprof_system_virtualwanlink_healthcheck:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -402,51 +402,57 @@ def main():
         'wanprof': {'required': True, 'type': 'str'},
         'wanprof_system_virtualwanlink_healthcheck': {
             'type': 'dict',
-            'v_range': [['6.0.0', '']],
+            'v_range': [['6.0.0', '7.6.2']],
             'options': {
                 '_dynamic-server': {'v_range': [['6.0.0', '6.4.15']], 'type': 'str'},
-                'addr-mode': {'choices': ['ipv4', 'ipv6'], 'type': 'str'},
-                'failtime': {'type': 'int'},
-                'http-agent': {'type': 'str'},
-                'http-get': {'type': 'str'},
-                'http-match': {'type': 'str'},
-                'interval': {'type': 'int'},
-                'members': {'type': 'raw'},
-                'name': {'required': True, 'type': 'str'},
-                'packet-size': {'type': 'int'},
-                'password': {'no_log': True, 'type': 'raw'},
-                'port': {'type': 'int'},
-                'protocol': {'choices': ['ping', 'tcp-echo', 'udp-echo', 'http', 'twamp', 'ping6', 'dns'], 'type': 'str'},
-                'recoverytime': {'type': 'int'},
-                'security-mode': {'choices': ['none', 'authentication'], 'type': 'str'},
-                'server': {'type': 'raw'},
+                'addr-mode': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['ipv4', 'ipv6'], 'type': 'str'},
+                'failtime': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'http-agent': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'http-get': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'http-match': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'interval': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'members': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'name': {'v_range': [['6.0.0', '7.6.2']], 'required': True, 'type': 'str'},
+                'packet-size': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'password': {'v_range': [['6.0.0', '7.6.2']], 'no_log': True, 'type': 'raw'},
+                'port': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'protocol': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['ping', 'tcp-echo', 'udp-echo', 'http', 'twamp', 'ping6', 'dns'], 'type': 'str'},
+                'recoverytime': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'security-mode': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['none', 'authentication'], 'type': 'str'},
+                'server': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
                 'sla': {
+                    'v_range': [['6.0.0', '7.6.2']],
                     'type': 'list',
                     'options': {
-                        'id': {'type': 'int'},
-                        'jitter-threshold': {'type': 'int'},
-                        'latency-threshold': {'type': 'int'},
-                        'link-cost-factor': {'type': 'list', 'choices': ['latency', 'jitter', 'packet-loss'], 'elements': 'str'},
-                        'packetloss-threshold': {'type': 'int'}
+                        'id': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                        'jitter-threshold': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                        'latency-threshold': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                        'link-cost-factor': {
+                            'v_range': [['6.0.0', '7.6.2']],
+                            'type': 'list',
+                            'choices': ['latency', 'jitter', 'packet-loss'],
+                            'elements': 'str'
+                        },
+                        'packetloss-threshold': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
-                'threshold-alert-jitter': {'type': 'int'},
-                'threshold-alert-latency': {'type': 'int'},
-                'threshold-alert-packetloss': {'type': 'int'},
-                'threshold-warning-jitter': {'type': 'int'},
-                'threshold-warning-latency': {'type': 'int'},
-                'threshold-warning-packetloss': {'type': 'int'},
-                'update-cascade-interface': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'update-static-route': {'choices': ['disable', 'enable'], 'type': 'str'},
+                'threshold-alert-jitter': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'threshold-alert-latency': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'threshold-alert-packetloss': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'threshold-warning-jitter': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'threshold-warning-latency': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'threshold-warning-packetloss': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'update-cascade-interface': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'update-static-route': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'internet-service-id': {'v_range': [['6.2.0', '7.2.0']], 'type': 'str'},
-                'probe-packets': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'sla-fail-log-period': {'v_range': [['6.2.0', '']], 'type': 'int'},
-                'sla-pass-log-period': {'v_range': [['6.2.0', '']], 'no_log': True, 'type': 'int'},
+                'probe-packets': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'sla-fail-log-period': {'v_range': [['6.2.0', '7.6.2']], 'type': 'int'},
+                'sla-pass-log-period': {'v_range': [['6.2.0', '7.6.2']], 'no_log': True, 'type': 'int'},
                 'timeout': {'v_range': [['6.2.0', '6.4.15']], 'type': 'int'},
-                'ha-priority': {'v_range': [['6.2.2', '']], 'type': 'int'},
-                'diffservcode': {'v_range': [['6.2.5', '']], 'type': 'str'},
-                'probe-timeout': {'v_range': [['6.2.5', '']], 'type': 'int'},
+                'ha-priority': {'v_range': [['6.2.2', '7.6.2']], 'type': 'int'},
+                'diffservcode': {'v_range': [['6.2.5', '7.6.2']], 'type': 'str'},
+                'probe-timeout': {'v_range': [['6.2.5', '7.6.2']], 'type': 'int'},
                 'dns-request-domain': {'v_range': [['6.4.0', '6.4.0']], 'type': 'str'},
                 'probe-count': {'v_range': [['6.4.0', '6.4.0']], 'type': 'int'},
                 'system-dns': {'v_range': [['6.4.0', '6.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'}
